@@ -230,7 +230,7 @@ class AddEditScenarioFrame(BaseFrame):
                 updated_modifiers.append(modifier_row)
 
         if self.edit:
-            scenario = self._scenarios.get_item(self.selected_scenario)
+            scenario = self._scenarios.get(self.selected_scenario)
             scenario.description = self.scenario_description_var.get()
 
             scenario.modifiers = updated_modifiers
@@ -632,8 +632,7 @@ class AddEditScenarioFrame(BaseFrame):
 
     def __populate_handlers(self, combo):
 
-        handlers = [handler.name
-                    for handler in self._handlers.get_items()] + [u'Scenario']
+        handlers = [self._handlers[handler].name for handler in self._handlers] + [u'Scenario']
 
         handlers.sort()
 
