@@ -10,7 +10,7 @@ logging = logging_helper.setup_logging()
 
 class HTTPSAllowedDomainsConfigWindow(ChildWindow):
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u"HTTPS Allowed Domains")
 
         self.config = HTTPSAllowedDomainsConfigFrame(parent=self._main_frame,
