@@ -22,7 +22,7 @@ class AddEditHTTPSDomainWindow(ChildWindow):
         super(AddEditHTTPSDomainWindow, self).__init__(*args,
                                                        **kwargs)
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u"Add/Edit HTTPS Domain")
 
         self.config = AddEditHTTPSDomainFrame(parent=self._main_frame,
