@@ -22,7 +22,7 @@ class AddEditRedirectURIWindow(ChildWindow):
         super(AddEditRedirectURIWindow, self).__init__(*args,
                                                        **kwargs)
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u"Add/Edit Redirect URI")
 
         self.config = AddEditRedirectURIFrame(parent=self._main_frame,
