@@ -17,7 +17,7 @@ class RedirectURIConfigWindow(ChildWindow):
         super(RedirectURIConfigWindow, self).__init__(*args,
                                                       **kwargs)
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u"Redirect URI Configuration")
 
         self.config = RedirectURIConfigFrame(parent=self._main_frame)
